@@ -279,7 +279,11 @@ class Update(object):
             print('\nMembers to invite: {}'.format(len(invite)))
             for login in sorted(invite):
                 print('   + {}'.format(login))
-                self.github.invite_org_member(login)
+                try:
+                    self.github.invite_org_member(login)
+                except Exception as e:
+                    print('ERROR: Failed to invite org member: {}'.format(login))
+                    print(e)
 
         if remove:
             print('\nMembers to remove: {}'.format(len(remove)))
